@@ -11,7 +11,7 @@
 #include <stdbool.h>
 #include <stdlib.h>
 #include <X11/Xlib.h>
-#include <monitor.h>
+#include "monitor.h"
 #include "tag.h"
 #include "floating.h"
 
@@ -43,8 +43,8 @@ enum {
     LAYOUT_COUNT,
 };
 
-extern char* g_align_names[];
-extern char* g_layout_names[];
+extern const char* g_align_names[];
+extern const char* g_layout_names[];
 
 enum {
     TYPE_CLIENTS = 0,
@@ -94,9 +94,10 @@ typedef struct HSFrame {
 
 
 // globals
-HSFrame*    g_cur_frame; // currently selected frame
-int* g_frame_gap;
-int* g_window_gap;
+extern HSFrame*    g_cur_frame; // currently selected frame
+extern int* g_frame_gap;
+extern int* g_window_gap;
+extern char* g_tree_style;
 
 // functions
 void layout_init();
@@ -104,7 +105,7 @@ void layout_destroy();
 // for frames
 HSFrame* frame_create_empty(HSFrame* parent, HSTag* parenttag);
 void frame_insert_client(HSFrame* frame, struct HSClient* client);
-HSFrame* lookup_frame(HSFrame* root, char* path);
+HSFrame* lookup_frame(HSFrame* root, const char* path);
 HSFrame* frame_current_selection();
 HSFrame* frame_current_selection_below(HSFrame* frame);
 // finds the subframe of frame that contains the window
@@ -179,6 +180,7 @@ int frame_move_window_command(int argc, char** argv, GString* output);
 /// removes the current frame
 int frame_remove_command(int argc, char** argv);
 int close_or_remove_command(int argc, char** argv);
+int close_and_remove_command(int argc, char** argv);
 void frame_set_visible(HSFrame* frame, bool visible);
 void frame_update_border(Window window, unsigned long color);
 
