@@ -23,21 +23,18 @@ typedef struct HSTag {
     struct HSObject* object;
 } HSTag;
 
-// globals
-GArray*     g_tags; // Array of HSTag*
-bool        g_tag_flags_dirty;
-
 void tag_init();
 void tag_destroy();
 
 // for tags
-HSTag* add_tag(char* name);
-HSTag* find_tag(char* name);
+HSTag* add_tag(const char* name);
+HSTag* find_tag(const char* name);
 int    tag_index_of(HSTag* tag);
 HSTag* find_unused_tag();
 HSTag* find_tag_with_toplevel_frame(struct HSFrame* frame);
 HSTag* get_tag_by_index(int index);
 HSTag* get_tag_by_index_str(char* index_str, bool skip_visible_tags);
+int    tag_get_count();
 int tag_add_command(int argc, char** argv, GString* output);
 int tag_rename_command(int argc, char** argv, GString* output);
 int tag_move_window_command(int argc, char** argv, GString* output);
